@@ -66,8 +66,9 @@ class Next
 
         static size_t addToKernel(Vector &next, Symbol const *symbol, 
                                   size_t stateItemOffset);
-        static bool hasSymbol(Next const &next, Symbol const *symbol);
-        static bool inLAset(Next const &next, LookaheadSet const &laSet);
+
+        bool hasSymbol(Symbol const *symbol) const;
+        bool inLAset(LookaheadSet const &laSet) const;
 
         static void removeShift(RmShift const &rmShift, Vector &nextVector,
                                 size_t *nRemoved);
@@ -76,11 +77,6 @@ class Next
                                             (std::ostream &out) const);
 };
 
-inline bool Next::hasSymbol(Next const &next, Symbol const *symbol)
-{
-    return next.d_symbol == symbol;
-}
-
 inline std::vector<size_t> const &Next::kernel() const
 {
     return d_kernel;
@@ -91,6 +87,11 @@ inline Symbol const *Next::symbol() const
     return d_symbol;
 }
 
+inline bool Next::hasSymbol(Symbol const *symbol) const
+{
+    return d_symbol == symbol;
+}
+
 inline Symbol const *Next::pSymbol() const
 {
     return d_symbol ? d_symbol : d_removed;
@@ -106,9 +107,9 @@ inline void Next::setNext(size_t next)
     d_next = next;
 }
 
-inline bool Next::inLAset(Next const &next, LookaheadSet const &laSet)
+inline bool Next::inLAset(LookaheadSet const &laSet) const
 {
-    return laSet >= next.d_symbol;
+    return laSet >= d_symbol;
 }
 
 inline void Next::inserter(std::ostream &(Next::*insertPtr)
