@@ -18,20 +18,28 @@ class NonTerminal: public Symbol
 
     private:
         Production::Vector d_production;  // production rules in a vector
-                                // of ptrs to Production objects
-        FirstSet    d_first;
-        FollowSet   d_follow;
+                                    // of ptrs to Production objects
 
-        size_t d_nr;          // the NonTerminal's number
+        FirstSet    d_first;        // set of terminals that can be
+                                    // encountered at this NonTerminal
 
-        static size_t s_counter;
-        static size_t s_number;   // incremented at each call of setNr()
-        static bool s_unused;
-        static bool s_undefined;
+        FollowSet   d_follow;       // set of terminals that can follow this
+                                    // NonTerminal 
+
+        size_t d_nr;                // the NonTerminal's number
+
+        static size_t s_counter;    // counts the number of symbols in follow
+                                    // sets. May be reset to 0 by
+                                    // resetCounter()
+        static size_t s_number;     // incremented at each call of setNr()
+        static bool s_unused;       // prevents multiple unused warnings
+        static bool s_undefined;    // set to true once at least one
+                                    // nonterminal is not used.
         
         static std::ostream &(NonTerminal::*s_insertPtr)(std::ostream &out)
                                                                         const;
-
+                                    // pointer to the insertion function to be
+                                    // used. 
     public:
         NonTerminal(std::string const &name, std::string const &stype = "",
                                 Type type = NON_TERMINAL);
@@ -41,9 +49,7 @@ class NonTerminal: public Symbol
         Production::Vector const &productions() const;
         size_t firstSize() const;
         size_t nProductions() const;
-        size_t value() const;
         std::set<Element const *> const &firstTerminals() const;
-        virtual FirstSet const &firstSet() const;
         void addEpsilon() ;
         void addProduction(Production *next);
         void addToFollow(FirstSet const &firstSet);
@@ -73,11 +79,12 @@ class NonTerminal: public Symbol
         std::ostream &nameAndFollowset(std::ostream &out) const;
                                     // the N's value 
         std::ostream &value(std::ostream &out) const;
-
-    protected:
-        virtual std::ostream &insert(std::ostream &out) const;
+        using Symbol::value;
 
     private:
+        virtual std::ostream &insert(std::ostream &out) const;
+        virtual size_t v_value() const;
+        virtual FirstSet const &v_firstSet() const;
         std::ostream &insName(std::ostream &out) const;
 };
 
@@ -108,7 +115,7 @@ inline std::ostream &NonTerminal::nameAndFollowset(std::ostream &out) const
 
 inline std::ostream &NonTerminal::value(std::ostream &out) const
 {
-    return out << std::setw(3) << value();
+    return out << std::setw(3) << v_value();
 }
 
 
@@ -149,10 +156,10 @@ inline size_t NonTerminal::firstSize() const
 
 inline std::set<Element const *> const &NonTerminal::firstTerminals() const
 {
-    return d_first;
+    return d_first.set();
 }
 
-inline FirstSet const &NonTerminal::firstSet() const
+inline FirstSet const &NonTerminal::v_firstSet() const
 {
     return d_first;
 }
@@ -167,7 +174,7 @@ inline size_t NonTerminal::nProductions() const
     return d_production.size();
 }
 
-inline size_t NonTerminal::value() const
+inline size_t NonTerminal::v_value() const
 {
     return d_nr;
 }
