@@ -10,6 +10,11 @@ class NonTerminal;
 class Terminal;
 class Symbol;
 
+namespace FBB
+{
+    class Mstream;
+}
+
 #undef Parser
 class Parser: public ParserBase
 {
@@ -21,6 +26,9 @@ class Parser: public ParserBase
     typedef ActionMap::value_type 
             Value;
 
+            // data members that are self-explanatory are not explicitly
+            // described here.
+
     FBB::Arg &d_arg;
 
     // $insert scannerobject
@@ -28,6 +36,8 @@ class Parser: public ParserBase
     Rules      &d_rules;
     Symtab      d_symtab;
 
+            // all the flags that can be set using directives/options
+
     bool        d_debugFlag;
     bool        d_errorVerbose;
     bool        d_generateBaseclass;
@@ -39,6 +49,8 @@ class Parser: public ParserBase
 
     size_t      d_requiredTokens;
 
+            // strings holding text set using directives/options
+
     std::string d_baseclassHeader;
     std::string d_baseclassSkeleton;
     std::string d_classHeader;
@@ -66,6 +78,7 @@ class Parser: public ParserBase
     std::vector<Block::Range>::const_reverse_iterator d_skipRbegin;
     std::vector<Block::Range>::const_reverse_iterator d_skipRend;
 
+            // strings containing default file and other names
     static char s_defaultBaseclassSkeleton[];
     static char s_defaultClassName[];
     static char s_defaultClassSkeleton[];
@@ -73,10 +86,6 @@ class Parser: public ParserBase
     static char s_defaultParsefunSkeleton[];
     static char s_defaultParsefunSource[];
 
-    static std::ofstream s_verbose;
-
-
-
     static size_t s_nHidden;          // number of hidden nonterminals
     static std::ostringstream s_hiddenName;
 
@@ -120,7 +129,7 @@ class Parser: public ParserBase
         void checkEmptyBlocktype();
         void checkFirstType();
 
-        std::ostream &lineMsg();
+        std::ostream &lineMsg(FBB::Mstream &mstream);
                                         
         bool defaultReturn(size_t pos, Block &block);
         Symbol *defineNonTerminal(std::string const &name, 
@@ -278,9 +287,9 @@ inline std::string const &Parser::implementationSkeleton() const
     return d_implementationSkeleton;
 }
 
-inline std::ostream &Parser::lineMsg()
+inline std::ostream &Parser::lineMsg(FBB::Mstream &mstream)
 {
-    return d_scanner.lineMsg();
+    return d_scanner.lineMsg(mstream);
 }
 
 inline bool Parser::lspNeeded() const
