@@ -3,7 +3,7 @@
 void Parser::setStart()
 {
     if (d_rules.startRule().size())
-        lineMsg() << "%start multiply specified" << err;
+        lineMsg(emsg) << "%start multiply specified" << endl;
     else
         d_rules.setStartRule(d_scanner.YYText());
 }
