@@ -5,6 +5,9 @@ void RRConflict::removeConflicts(StateItem::Vector &itemVector)
     for_each
     (
         d_rmReduction.begin(), d_rmReduction.end(),
-        FnWrap::unary(StateItem::removeRRConflict, itemVector)
+        [&](RRData const &rm)
+        {
+           StateItem::removeRRConflict(rm, itemVector);
+        }
     );
 }
