@@ -7,6 +7,11 @@
 
 void Rules::updatePrecedences()
 {   
-    for_each(d_production.begin(), d_production.end(),
-        FnWrap::unary(updatePrecedence, d_terminal));
+    for_each(
+        d_production.begin(), d_production.end(),
+        [&](Production *production)
+        {
+            updatePrecedence(production, d_terminal);
+        }
+    );
 }
