@@ -29,14 +29,12 @@ $insert 4 scannerobject
 
 inline void \@::error(char const *msg)
 {
-    std::cerr << msg << std::endl;
+    std::cerr << msg << '\n';
 }
 
 $insert lex
 
-inline void \@::print()      // use d_token, d_loc
-{}
-
+$insert print
 $insert namespace-close
 
 #endif
