@@ -5,6 +5,9 @@ void SRConflict::removeReductions(StateItem::Vector &itemVector)
     for_each
     (
         d_rmReduction.begin(), d_rmReduction.end(),
-        FnWrap::unary(StateItem::removeReduction, itemVector)
+        [&](RmReduction const &rm)
+        {
+            StateItem::removeReduction(rm, itemVector);
+        }
     );
 }
