@@ -152,7 +152,13 @@ void State::define()
         // reaching this state and its type is NORMAL: ACCEPT. Pondering...
     s_acceptState->d_stateType.setType(StateType::REQ_TOKEN);
 
-    for_each(s_state.begin(), s_state.end(), staticCheckConflicts);
+    for_each(
+        s_state.begin(), s_state.end(),
+        [](State *state)
+        {
+            state->checkConflicts();
+        }
+    );
 
     if 
     (
@@ -170,5 +176,15 @@ void State::define()
                     " Reduce/Reduce conflict(s)" << endl;
     }
 
-    for_each(s_state.begin(), s_state.end(), staticSummarizeActions);
+    for_each(
+        s_state.begin(), s_state.end(),
+        [](State *state)
+        {
+            state->summarizeActions();
+        }
+    );
 }
+
+
+
+
