@@ -8,8 +8,13 @@ void State::distributeLA(Next &next, LookaheadContext &context)
     context.visitChildState = false;
 
         // visit all kernel items of the child state
-    for_each (next.kernel().begin(), next.kernel().end(),
-        FnWrap::unary(updateLA, context));
+    for_each(
+        next.kernel().begin(), next.kernel().end(),
+        [&](size_t itemIdx)
+        {
+            updateLA(itemIdx, context);
+        }
+    );
 
         // if the child's state has its LA changed, make sure it's visited
     if (context.visitChildState)
