@@ -15,8 +15,12 @@ void State::propagateLA()
     (
         find_if(
             d_itemVector.begin(), d_itemVector.end(), 
-            FnWrap::unary(StateItem::propagateLA, d_itemVector)
-        ) != d_itemVector.end()
+            [&](StateItem &stateItem)
+            {
+                return StateItem::propagateLA(stateItem, d_itemVector);
+            }
+        ) 
+        != d_itemVector.end()
     )
         ;
 
@@ -30,11 +34,26 @@ void State::propagateLA()
                            // remaining fields managed by distributeLA
     };
 
-    for_each(d_nextVector.begin(), d_nextVector.end(),
-        FnWrap::unary(distributeLA, context));
+    for_each(
+        d_nextVector.begin(), d_nextVector.end(),
+        [&](Next &next)
+        {
+            distributeLA(next, context);
+        }
+    );
 
-    for_each(context.child.begin(), context.child.end(), staticPropagateLA);
+    for_each(
+        context.child.begin(), context.child.end(), 
+        [](State *state)
+        {
+            state->propagateLA();   
+        }
+    );
 }
 
 
 
+
+
+
+
