@@ -10,8 +10,13 @@ void Writer::productions() const
             "{\n"
             "     {0, 0}, // not used: reduction values are negative\n";
 
-    for_each(prods.begin(), prods.end(),
-             FnWrap::unary(productionInfo, *d_out));
+    for_each(
+        prods.begin(), prods.end(),
+        [=](Production const *production)
+        {
+            productionInfo(production, *d_out);
+        }
+    );
 
     *d_out << "};\n";
 }
